
     function  r=codeKdV_RHS(u, N, B, mu, p)

     for j=1:N
       y(j)=(-1)^(j-1)*u(j);
     end

     Fu=fft(y);

     for k=1:N
       y(k)=(k-1-N/2)*Fu(k);  Fu(k)=(k-1-N/2)^3*Fu(k);
     end

     y=ifft(y);  Fu=ifft(Fu);

     for j=1:N
        ss=-i*B*(pi/p)*u(j)*y(j)+i*mu*(pi/p)^3*Fu(j);
        r(j)=(-1)^(j-1)*ss;
     end
       

