
for N=1:100

    D1=DM1(N);  

    for i=1:N
        for j=1:N
          A(i,j)=D1(i+1,j+1);
        end
    end

    aa=max(abs(eig(A)))
    cc=min(abs(eig(A)));
    bb=aa/cc;

    xx(N)=N;
    err(N)=aa/(N^2);
    frr(N)=bb/(N^2);
    grr(N)=cc;

end

%    fprintf(1,      '%16.0f          %13.3e  \n', [xx;  frr]);

    semilogy (xx, frr)
    

